@@ -14,7 +14,7 @@ documentation = {}
 documentation['help'] = """Felix Felicis %(version)s
 
 Usage:
-    liquidluck create [-s <file>|--settings=<file>]
+    liquidluck init [-s <file>|--settings=<file>]
     liquidluck build [-s <file>|--settings=<file>] [-v|--verbose]
     liquidluck server [-s <file>|--settings=<file>] [-p <port>|--port=<port>]
     liquidluck search [<theme>] [-c|--clean] [-f|--force]
@@ -37,9 +37,9 @@ Options:
     'webhook': '[-s <file>|--settings=<file>] [-p <port>|--port=<port>]'
 }
 
-documentation['create'] = """
+documentation['init'] = """
 Usage:
-    liquidluck create [-s <file>|--settings=<file>]
+    liquidluck init [-s <file>|--settings=<file>]
 
 Options:
     -h --help               show this screen.
@@ -112,14 +112,14 @@ def main():
 
     arg_settings = args.get('--settings') or generator.find_settings()
     arg_verbose = args.get('--verbose')
-    arg_port = int(args.get('--port') or 8000)
+    arg_port = args.get('--port') or '8000'
 
     arg_theme = args.get('<theme>') or None
     arg_clean = args.get('--clean')
     arg_force = args.get('--force')
     arg_global = args.get('--global')
 
-    if command == 'create':
+    if command == 'init':
         generator.create_settings(arg_settings)
     elif command == 'build':
         if not arg_settings:
@@ -134,12 +134,12 @@ def main():
             g.detail_logging = arg_verbose
             generator.build(arg_settings)
     elif command == 'server':
-        if not os.path.exists(arg_settings):
+        if arg_settings and os.path.exists(arg_settings):
+            generator.load_settings(arg_settings)
+        else:
             print('setting file not found')
             server.config(arg_port)
             server.start_server()
-        else:
-            generator.load_settings(arg_settings)
 
         permalink = settings.config.get('permalink')
         if permalink.endswith('.html'):
